pub struct MockCiphersApi {
CiphersApi_expectations: MockCiphersApi_CiphersApi,
}Fields
CiphersApi_expectations: MockCiphersApi_CiphersApiImplementations
Sourceimpl MockCiphersApi
impl MockCiphersApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockCiphersApi
impl MockCiphersApi
Sourcepub fn expect_azure_validate_file(&mut self) -> &mut Expectation
pub fn expect_azure_validate_file(&mut self) -> &mut Expectation
Create an Expectation for mocking the azure_validate_file method
Sourcepub fn expect_delete(&mut self) -> &mut Expectation
pub fn expect_delete(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete method
Sourcepub fn expect_delete_admin(&mut self) -> &mut Expectation
pub fn expect_delete_admin(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete_admin method
Sourcepub fn expect_delete_attachment(&mut self) -> &mut Expectation
pub fn expect_delete_attachment(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete_attachment method
Sourcepub fn expect_delete_attachment_admin(&mut self) -> &mut Expectation
pub fn expect_delete_attachment_admin(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete_attachment_admin method
Sourcepub fn expect_delete_many(&mut self) -> &mut Expectation
pub fn expect_delete_many(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete_many method
Sourcepub fn expect_delete_many_admin(&mut self) -> &mut Expectation
pub fn expect_delete_many_admin(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete_many_admin method
Sourcepub fn expect_download_attachment(&mut self) -> &mut Expectation
pub fn expect_download_attachment(&mut self) -> &mut Expectation
Create an Expectation for mocking the download_attachment method
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_get_admin(&mut self) -> &mut Expectation
pub fn expect_get_admin(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_admin method
Sourcepub fn expect_get_all(&mut self) -> &mut Expectation
pub fn expect_get_all(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_all method
Sourcepub fn expect_get_assigned_organization_ciphers(&mut self) -> &mut Expectation
pub fn expect_get_assigned_organization_ciphers(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_assigned_organization_ciphers method
Sourcepub fn expect_get_attachment_data(&mut self) -> &mut Expectation
pub fn expect_get_attachment_data(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_attachment_data method
Sourcepub fn expect_get_attachment_data_admin(&mut self) -> &mut Expectation
pub fn expect_get_attachment_data_admin(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_attachment_data_admin method
Sourcepub fn expect_get_details(&mut self) -> &mut Expectation
pub fn expect_get_details(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_details method
Sourcepub fn expect_get_organization_ciphers(&mut self) -> &mut Expectation
pub fn expect_get_organization_ciphers(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_organization_ciphers method
Sourcepub fn expect_move_many(&mut self) -> &mut Expectation
pub fn expect_move_many(&mut self) -> &mut Expectation
Create an Expectation for mocking the move_many method
Sourcepub fn expect_post(&mut self) -> &mut Expectation
pub fn expect_post(&mut self) -> &mut Expectation
Create an Expectation for mocking the post method
Sourcepub fn expect_post_admin(&mut self) -> &mut Expectation
pub fn expect_post_admin(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_admin method
Sourcepub fn expect_post_attachment(&mut self) -> &mut Expectation
pub fn expect_post_attachment(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_attachment method
Sourcepub fn expect_post_attachment_admin(&mut self) -> &mut Expectation
pub fn expect_post_attachment_admin(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_attachment_admin method
Create an Expectation for mocking the post_attachment_share method
Sourcepub fn expect_post_bulk_collections(&mut self) -> &mut Expectation
pub fn expect_post_bulk_collections(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_bulk_collections method
Sourcepub fn expect_post_create(&mut self) -> &mut Expectation
pub fn expect_post_create(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_create method
Sourcepub fn expect_post_file_for_existing_attachment(&mut self) -> &mut Expectation
pub fn expect_post_file_for_existing_attachment(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_file_for_existing_attachment method
Sourcepub fn expect_post_purge(&mut self) -> &mut Expectation
pub fn expect_post_purge(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_purge method
Sourcepub fn expect_put(&mut self) -> &mut Expectation
pub fn expect_put(&mut self) -> &mut Expectation
Create an Expectation for mocking the put method
Sourcepub fn expect_put_admin(&mut self) -> &mut Expectation
pub fn expect_put_admin(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_admin method
Sourcepub fn expect_put_archive(&mut self) -> &mut Expectation
pub fn expect_put_archive(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_archive method
Sourcepub fn expect_put_archive_many(&mut self) -> &mut Expectation
pub fn expect_put_archive_many(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_archive_many method
Sourcepub fn expect_put_collections(&mut self) -> &mut Expectation
pub fn expect_put_collections(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_collections method
Sourcepub fn expect_put_collections_admin(&mut self) -> &mut Expectation
pub fn expect_put_collections_admin(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_collections_admin method
Sourcepub fn expect_put_collections_v_next(&mut self) -> &mut Expectation
pub fn expect_put_collections_v_next(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_collections_v_next method
Sourcepub fn expect_put_delete(&mut self) -> &mut Expectation
pub fn expect_put_delete(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_delete method
Sourcepub fn expect_put_delete_admin(&mut self) -> &mut Expectation
pub fn expect_put_delete_admin(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_delete_admin method
Sourcepub fn expect_put_delete_many(&mut self) -> &mut Expectation
pub fn expect_put_delete_many(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_delete_many method
Sourcepub fn expect_put_delete_many_admin(&mut self) -> &mut Expectation
pub fn expect_put_delete_many_admin(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_delete_many_admin method
Sourcepub fn expect_put_partial(&mut self) -> &mut Expectation
pub fn expect_put_partial(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_partial method
Sourcepub fn expect_put_restore(&mut self) -> &mut Expectation
pub fn expect_put_restore(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_restore method
Sourcepub fn expect_put_restore_admin(&mut self) -> &mut Expectation
pub fn expect_put_restore_admin(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_restore_admin method
Sourcepub fn expect_put_restore_many(&mut self) -> &mut Expectation
pub fn expect_put_restore_many(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_restore_many method
Sourcepub fn expect_put_restore_many_admin(&mut self) -> &mut Expectation
pub fn expect_put_restore_many_admin(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_restore_many_admin method
Create an Expectation for mocking the put_share method
Create an Expectation for mocking the put_share_many method
Sourcepub fn expect_put_unarchive(&mut self) -> &mut Expectation
pub fn expect_put_unarchive(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_unarchive method
Sourcepub fn expect_put_unarchive_many(&mut self) -> &mut Expectation
pub fn expect_put_unarchive_many(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_unarchive_many method
Sourcepub fn expect_renew_file_upload_url(&mut self) -> &mut Expectation
pub fn expect_renew_file_upload_url(&mut self) -> &mut Expectation
Create an Expectation for mocking the renew_file_upload_url method